CTDvis
======

[![PyPi version](https://pypip.in/v/ctdvis/badge.png)](https://pypi.python.org/pypi/ctdvis/)
[![PyPi wheel](https://pypip.in/wheel/ctdvis/badge.svg)](https://pypi.python.org/pypi/ctdvis/)
[![PyPI license](https://img.shields.io/pypi/l/ansicolortags.svg)](https://pypi.python.org/pypi/ansicolortags/)

Python 3 library developed by Shd at SMHI.

- Visualize high resolution oceanographic profile data, eg. CTD, MVP.
- Main purpose: Quality control

See [script examples](https://github.com/sharksmhi/ctdvis/tree/master/ctdvis/tests)

Installation
------------
CTDvis can be installed from PyPI with pip:

```bash
pip install ctdvis
```

Example visualization
--------

![Example Screen](docs/screenshot.PNG)

![Example single_plot](docs/single_plot.PNG) 

![Example Flag data](docs/flag_plot.PNG)
